@@ -199,25 +199,18 @@ def init():
                     res=origin.pull()
                     print("Looking for Pull Opeartion")
                     flag=flag+1
-                    print("1")
                     time.sleep(60)
+                    response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name,'Time ':curtime,'user_name':username,'message':"pull success",'status':'pull operation performed'})
                     
                     
                 else:
                     print("no files to pull")
                     time.sleep(60)
                     flag=0
+                    response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name,'Time ':curtime,'user_name':username,'message': "pull failed",'status':'pull operation performed'})
+
 
             curtime = datetime.datetime.now()
-            print("2")
-
-            if flag > 0:
-                response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name,'Time ':curtime,'user_name':username,'message':"pull success",'status':'pull operation performed'})
-            
-            else:
-                response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name,'Time ':curtime,'user_name':username,'message': "pull failed",'status':'pull operation performed'})
-
-            print(response2.status_code)
            #success , project id , repo name , current date and time , email id'
     
 
